Jeroen De Dauw has submitted this change and it was merged.

Change subject: Use American English spelling for behavior
......................................................................


Use American English spelling for behavior

Change-Id: I92a9a39b5024bd5bbcd803c18ccecfff1a7fd78e
---
M RELEASE-NOTES-1.9
M SemanticMediaWiki.settings.php
M includes/datavalues/SMW_DV_Time.php
M includes/datavalues/SMW_DV_WikiPage.php
M includes/queryprinters/SMW_QP_Aggregatable.php
M includes/storage/SQLStore/SMW_DIHandler_Concept.php
M includes/storage/SQLStore/SMW_SQLStore3_Writers.php
M releasenotes/RELEASE-NOTES
M releasenotes/RELEASE-NOTES-1.7
M releasenotes/RELEASE-NOTES-1.8
M specials/AskSpecial/SMW_QueryUI.php
11 files changed, 15 insertions(+), 15 deletions(-)

Approvals:
  Jeroen De Dauw: Verified; Looks good to me, approved
  jenkins-bot: Verified



diff --git a/RELEASE-NOTES-1.9 b/RELEASE-NOTES-1.9
index 2d1e5bb..890aa53 100644
--- a/RELEASE-NOTES-1.9
+++ b/RELEASE-NOTES-1.9
@@ -13,7 +13,7 @@
 * Restored compatibility with SQLite
 * Support for quantity export via API and JSON format (I17a3e046)
 * Removed old storage implementation SMWSQLStore2, superseded by SMWSQLStore3 
in SMW 1.8
-* #set_recurring_event create individual subobjects (changes query behaviour 
for recurring events; for more see [[Help:Recurring_events]]) (I5db911e536)
+* #set_recurring_event create individual subobjects (changes query behavior 
for recurring events; for more see [[Help:Recurring_events]]) (I5db911e536)
 
 === New features ===
 
@@ -63,4 +63,4 @@
 === Extended translations ===
 
 As usual, translations have been extended thanks to the 
[[Translatewiki.net|Translatewiki.net project]].
-In addition, the core strings (SMW properties and datatypes) for Slovak have 
been updated.
\ No newline at end of file
+In addition, the core strings (SMW properties and datatypes) for Slovak have 
been updated.
diff --git a/includes/datavalues/SMW_DV_Time.php 
b/includes/datavalues/SMW_DV_Time.php
index d1b6748..194eafe 100644
--- a/includes/datavalues/SMW_DV_Time.php
+++ b/includes/datavalues/SMW_DV_Time.php
@@ -18,7 +18,7 @@
  * purposes, incomplete dates are completed with defaults (usually using the
  * earliest possible time, i.e. interpreting "2008" as "Jan 1 2008 00:00:00").
  * The information on what was unspecified is kept internally for improving
- * behaviour e.g. for outputs (defaults are not printed when querying for a
+ * behavior e.g. for outputs (defaults are not printed when querying for a
  * value). This largely uses the precision handling of SMWDITime.
  *
  *
diff --git a/includes/datavalues/SMW_DV_WikiPage.php 
b/includes/datavalues/SMW_DV_WikiPage.php
index 16b030c..ba6e004 100644
--- a/includes/datavalues/SMW_DV_WikiPage.php
+++ b/includes/datavalues/SMW_DV_WikiPage.php
@@ -12,7 +12,7 @@
  * namespace, Whether a namespace is fixed is decided based on the
  * type ID when the object is constructed.
  *
- * The short display simulates the behaviour of the MediaWiki "pipe trick"
+ * The short display simulates the behavior of the MediaWiki "pipe trick"
  * but always includes fragments. This can be overwritten by setting a
  * caption, which is also done by default when generating a value from user
  * input. The long display always includes all relevant information. Only if a
diff --git a/includes/queryprinters/SMW_QP_Aggregatable.php 
b/includes/queryprinters/SMW_QP_Aggregatable.php
index 0620936..edbca8e 100644
--- a/includes/queryprinters/SMW_QP_Aggregatable.php
+++ b/includes/queryprinters/SMW_QP_Aggregatable.php
@@ -3,7 +3,7 @@
 /**
  * Result printer that supports the distribution parameter,
  * and related parameters. It allows the user to choose between
- * regular behaviour or getting a distribution of values.
+ * regular behavior or getting a distribution of values.
  *
  * For example, this result set: foo bar baz foo bar bar ohi
  * Will be turned into
diff --git a/includes/storage/SQLStore/SMW_DIHandler_Concept.php 
b/includes/storage/SQLStore/SMW_DIHandler_Concept.php
index 88e5bb7..b014641 100644
--- a/includes/storage/SQLStore/SMW_DIHandler_Concept.php
+++ b/includes/storage/SQLStore/SMW_DIHandler_Concept.php
@@ -7,7 +7,7 @@
 /**
  * This class implements Store access to Concept data items.
  *
- * @note The table layout and behaviour of this class is not coherent with the
+ * @note The table layout and behavior of this class is not coherent with the
  * way that other DIs work. This is because of the unfortunate use of the
  * concept table to store extra cache data, but also due to the design of
  * concept DIs. This will be cleaned up at some point.
diff --git a/includes/storage/SQLStore/SMW_SQLStore3_Writers.php 
b/includes/storage/SQLStore/SMW_SQLStore3_Writers.php
index 5aa47e5..9020da6 100644
--- a/includes/storage/SQLStore/SMW_SQLStore3_Writers.php
+++ b/includes/storage/SQLStore/SMW_SQLStore3_Writers.php
@@ -687,7 +687,7 @@
                        /// redirects are not supported by MW or SMW, the above 
is maximally correct in this case too.
                        /// NOTE: this temporarily leaves existing redirects to 
oldtitle point to newtitle as well, which
                        /// will be lost after the next update. Since double 
redirects are an error anyway, this is not
-                       /// a bad behaviour: everything will continue to work 
until the existing redirects are updated,
+                       /// a bad behavior: everything will continue to work 
until the existing redirects are updated,
                        /// which will hopefully be done to fix the double 
redirect.
                } else { // General move method: should always be correct
                        // (equality support respected when updating redirects)
diff --git a/releasenotes/RELEASE-NOTES b/releasenotes/RELEASE-NOTES
index bce93fd..25c3381 100644
--- a/releasenotes/RELEASE-NOTES
+++ b/releasenotes/RELEASE-NOTES
@@ -31,7 +31,7 @@
 * Compatibility with MediaWiki 1.17
 * Added << and >> comparators for strict comparisons. Also added ≤ and ≥ for
   non-strict comparisons. And introduced $smwStrictComparators setting that
-  allows changing the behaviour of < and > to doing strict comparisons.
+  allows changing the behavior of < and > to doing strict comparisons.
 * Various style and documentation improvements and translation updates.
 
 == SMW 1.5.2 ==
@@ -380,7 +380,7 @@
 
 * Experimental Postgres support.
 * More liberal parsing for geographic coordinates, most user inputs accepted 
now.
-* Improved URL datatype: better linking behaviour, tolerant towards 
Unicode-URLs.
+* Improved URL datatype: better linking behavior, tolerant towards 
Unicode-URLs.
 * Significantly improved performance for RDF export.
 * Complete translations for Fr, Zh-tw, and Zh-ch added.
 * Various minor bugfixes.
diff --git a/releasenotes/RELEASE-NOTES-1.7 b/releasenotes/RELEASE-NOTES-1.7
index 4a6b1f1..ab46062 100644
--- a/releasenotes/RELEASE-NOTES-1.7
+++ b/releasenotes/RELEASE-NOTES-1.7
@@ -26,7 +26,7 @@
 * Fixed some issues with the category result format (including bug 30761).
 * Fixed email validation issue (bug 32295).
 * Fixed incorrect handling of sort and order parameters on Special:Ask (bug 
32706).
-* Fixed display of images to old behaviour after a recent regression.
+* Fixed display of images to old behavior after a recent regression.
 * Fixed fatal error in the concept cache maintenance script (bug 32592).
 * Fixed factbox links to Special:SearchByProperty containing numerical numbers 
for
   wikis in languages with the comma as decimal separator instead of a dot.
diff --git a/releasenotes/RELEASE-NOTES-1.8 b/releasenotes/RELEASE-NOTES-1.8
index 411c573..0fc0e25 100644
--- a/releasenotes/RELEASE-NOTES-1.8
+++ b/releasenotes/RELEASE-NOTES-1.8
@@ -14,7 +14,7 @@
 * Added atom printer (bug 38636)
 * SMW now collects data about all queries, and this data can be queried to get 
an overview of queries used on the wiki. Information about queries is stored in 
subobjects of the page they are on. The property [[Property:Has query]] links a 
page to a query. The query subobject currently holds values for the following 
properties: [[Property:Query string]], [[Property:Query format]], 
[[Property:Query size]], [[Property:Query depth]].
 * Added new info tooltip (bug 37361)
-* Added two new output formats for properties of type Time, "Gr" and "Jl", to 
set the desired calendar model for display in #ask results. If nothing is 
given, SMW will select the calendar based on the date as before (Julian 
calendar defaults from until 4th Oct 1582). As before. the same behaviour is 
used when entering dates, and "Jl" and "Gr" also work in this case.
+* Added two new output formats for properties of type Time, "Gr" and "Jl", to 
set the desired calendar model for display in #ask results. If nothing is 
given, SMW will select the calendar based on the date as before (Julian 
calendar defaults from until 4th Oct 1582). As before. the same behavior is 
used when entering dates, and "Jl" and "Gr" also work in this case.
 * Added new output format "nowiki" to properties of type URL, which will 
format a URL in such a way that it will not be autolinked by MediaWiki.
 
 === Enhancements ===
@@ -74,4 +74,4 @@
 
 === Extended translations ===
 
-As usual, translations have been extended thanks to the 
[[Translatewiki.net|Translatewiki.net project]].
\ No newline at end of file
+As usual, translations have been extended thanks to the 
[[Translatewiki.net|Translatewiki.net project]].
diff --git a/specials/AskSpecial/SMW_QueryUI.php 
b/specials/AskSpecial/SMW_QueryUI.php
index e7fda0c..e47d556 100644
--- a/specials/AskSpecial/SMW_QueryUI.php
+++ b/specials/AskSpecial/SMW_QueryUI.php
@@ -1669,7 +1669,7 @@
         * elements of an array.Use in conjunction with processFormatOptions() 
to
         * supply formats options using ajax. Also, use its complement
         * processFormatSelectBox() to decode form data sent by these elements.
-        * UI's may overload these methods to change behaviour or form
+        * UI's may overload these methods to change behavior or form
         * parameters.
         *
         * @param string $defaultFormat The default format which remains 
selected in the form

diff --git a/SemanticMediaWiki.settings.php b/SemanticMediaWiki.settings.php
index e31ed4d..5a590c3 100644
--- a/SemanticMediaWiki.settings.php
+++ b/SemanticMediaWiki.settings.php
@@ -298,7 +298,7 @@
 $smwgQDefaultLimit = 50;      // Default number of rows returned in a query. 
Can be increased with limit=num in #ask
 $smwgQMaxInlineLimit = 500;   // Max number of rows ever printed in a single 
inline query on a single page.
 $smwgQPrintoutLimit  = 100;   // Max number of supported printouts (added 
columns in result table, ?-statements)
-$smwgQDefaultLinking = 'all'; // Default linking behaviour. Can be one of 
"none", "subject" (first column), "all".
+$smwgQDefaultLinking = 'all'; // Default linking behavior. Can be one of 
"none", "subject" (first column), "all".
 
 
 ###
@@ -474,7 +474,7 @@
 
 ###
 # Properties (usually given as internal ids or DB key versions of property
 # titles) that are relevant for declaring the behaviour of a property P on a
 # property page in the sense that changing their values requires that all
 # pages that use P must be processed again. For example, if _PVAL (allowed
 # values) for a property change, then pages must be processed again. This
@@ -474,7 +474,7 @@
 ###
 # Properties (usually given as internal ids or DB key versions of property
-# titles) that are relevant for declaring the behaviour of a property P on a
+# titles) that are relevant for declaring the behavior of a property P on a
 # property page in the sense that changing their values requires that all
 # pages that use P must be processed again. For example, if _PVAL (allowed
-- 
To view, visit https://gerrit.wikimedia.org/r/52011
To unsubscribe, visit https://gerrit.wikimedia.org/r/settings

Gerrit-MessageType: merged
Gerrit-Change-Id: I92a9a39b5024bd5bbcd803c18ccecfff1a7fd78e
Gerrit-PatchSet: 1
Gerrit-Project: mediawiki/extensions/SemanticMediaWiki
Gerrit-Branch: master
Gerrit-Owner: Siebrand <[email protected]>
Gerrit-Reviewer: Jeroen De Dauw <[email protected]>
Gerrit-Reviewer: Raimond Spekking <[email protected]>
Gerrit-Reviewer: jenkins-bot

_______________________________________________
MediaWiki-commits mailing list
[email protected]
https://lists.wikimedia.org/mailman/listinfo/mediawiki-commits

Reply via email to